@@ -41,17 +41,20 @@ public:
   ImageView(QWidget* parent = nullptr);
   virtual ~ImageView();
 
+  QGraphicsItem* imageGraphicsItem() const;
+  QGraphicsItem* outlineGraphicsItem() const;
+
   void setImage(const QImage& image, bool show = true);
   void setGifAnimation(const QString& fileName);
   void setSVG(const QString& fileName);
 
-  QImage image() {
+  QImage image() const {
     return image_;
   }
 
   void setScaleFactor(double scale);
 
-  double scaleFactor() {
+  double scaleFactor() const {
     return scaleFactor_;
   }
 
@@ -60,7 +63,7 @@ public:
   void zoomFit();
   void zoomOriginal();
 
-  bool autoZoomFit() {
+  bool autoZoomFit() const {
     return autoZoomFit_;
   }
 
@@ -109,7 +112,9 @@ private:
                  const QPoint &start,
                  const QPoint &end,
                  qreal tipAngle,
-                 int tipLen) const;
+                 int tipLen);
+
+  void removeAnnotations();
 
 private Q_SLOTS:
   void onFileDropped(const QString file);
@@ -132,6 +137,7 @@ private:
   bool isSVG; // is the image an SVG file?
   Tool currentTool; // currently selected tool
   QPoint startPoint; // starting point for the tool
+  QList<QGraphicsItem *> annotations;	//annotation items which have been drawn in the scene
   int nextNumber;
   bool showOutline_;
 };
