@@ -104,23 +104,26 @@ MainWindow::MainWindow():
 
   // install an event filter on the image view
   ui.view->installEventFilter(this);
+
   ui.view->setBackgroundBrush(QBrush(settings.bgColor()));
+
   ui.view->updateOutline();
+
   ui.view->showOutline(settings.isOutlineShown());
   ui.actionShowOutline->setChecked(settings.isOutlineShown());
 
-  if(settings.showThumbnails())
-    setShowThumbnails(true);
+  setShowThumbnails(settings.showThumbnails());
+  ui.actionShowThumbnails->setChecked(settings.showThumbnails());
 
   ui.annotationsToolBar->setVisible(settings.isAnnotationsToolbarShown());
   ui.actionAnnotations->setChecked(settings.isAnnotationsToolbarShown());
-  connect(ui.actionAnnotations, &QAction::triggered, [this](int checked) {
+  connect(ui.actionAnnotations, &QAction::triggered, this, [this](int checked) {
     if(!isFullScreen()) { // annotations toolbar is hidden in fullscreen
       ui.annotationsToolBar->setVisible(checked);
     }
   });
   // annotations toolbar visibility can change in its context menu
-  connect(ui.annotationsToolBar, &QToolBar::visibilityChanged, [this](int visible) {
+  connect(ui.annotationsToolBar, &QToolBar::visibilityChanged, this, [this](int visible) {
     if(!isFullScreen()) { // annotations toolbar is hidden in fullscreen
       ui.actionAnnotations->setChecked(visible);
     }
@@ -203,8 +206,8 @@ MainWindow::~MainWindow() {
 void MainWindow::on_actionAbout_triggered() {
   QMessageBox::about(this, tr("About"),
                      tr("LXImage-Qt - a simple and fast image viewer\n\n"
-                     "Copyright (C) 2013\n"
-                     "LXQt Project: https://lxqt.org/\n\n"
+                     "Copyright (C) 2013-2020\n"
+                     "LXQt Project: https://lxqt-project.org\n\n"
                      "Authors:\n"
                      "Hong Jen Yee (PCMan) <pcman.tw@gmail.com>"));
 }
@@ -572,14 +575,19 @@ void MainWindow::onImageLoaded() {
 
     loadJob_ = nullptr; // the job object will be freed later automatically
 
+    // set image zoom, like in loadImage()
+    if(static_cast<Application*>(qApp)->settings().forceZoomFit()) {
+      ui.actionZoomFit->setChecked(true);
+    }
     ui.view->setAutoZoomFit(ui.actionZoomFit->isChecked());
     if(ui.actionOriginalSize->isChecked()) {
       ui.view->zoomOriginal();
     }
+
     ui.view->setImage(image_);
 
-   // currentIndex_ should be corrected after loading
-   currentIndex_ = indexFromPath(currentFile_);
+    // currentIndex_ should be corrected after loading
+    currentIndex_ = indexFromPath(currentFile_);
 
     updateUI();
 
@@ -608,7 +616,9 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event) {
       case QEvent::Wheel: { // mouse wheel event
         QWheelEvent* wheelEvent = static_cast<QWheelEvent*>(event);
         if(wheelEvent->modifiers() == 0) {
-          int delta = wheelEvent->delta();
+          QPoint angleDelta = wheelEvent->angleDelta();
+          Qt::Orientation orient = (qAbs(angleDelta.x()) > qAbs(angleDelta.y()) ? Qt::Horizontal : Qt::Vertical);
+          int delta = (orient == Qt::Horizontal ? angleDelta.x() : angleDelta.y());
           if(delta < 0)
             on_actionNext_triggered(); // next image
           else
@@ -631,7 +641,9 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event) {
       case QEvent::Wheel: { // mouse wheel event
         QWheelEvent* wheelEvent = static_cast<QWheelEvent*>(event);
         if(wheelEvent->modifiers() == 0) {
-          int delta = wheelEvent->delta();
+          QPoint angleDelta = wheelEvent->angleDelta();
+          Qt::Orientation orient = (qAbs(angleDelta.x()) > qAbs(angleDelta.y()) ? Qt::Horizontal : Qt::Vertical);
+          int delta = (orient == Qt::Horizontal ? angleDelta.x() : angleDelta.y());
           QScrollBar* hscroll = thumbnailsView_->childView()->horizontalScrollBar();
           if(hscroll)
             hscroll->setValue(hscroll->value() - delta);
@@ -780,7 +792,10 @@ void MainWindow::loadImage(const Fm::FilePath & filePath, QModelIndex index) {
     }
     const Fm::CStrPtr file_name = currentFile_.toString();
 
-    // like in onImageLoaded()
+    // set image zoom, like in onImageLoaded()
+    if(static_cast<Application*>(qApp)->settings().forceZoomFit()) {
+      ui.actionZoomFit->setChecked(true);
+    }
     ui.view->setAutoZoomFit(ui.actionZoomFit->isChecked());
     if(ui.actionOriginalSize->isChecked()) {
       ui.view->zoomOriginal();
