@@ -106,7 +106,9 @@ private Q_SLOTS:
   void on_actionRotateCounterclockwise_triggered();
   void on_actionFlipVertical_triggered();
   void on_actionFlipHorizontal_triggered();
+  void on_actionResize_triggered();
   void on_actionCopy_triggered();
+  void on_actionCopyPath_triggered();
   void on_actionPaste_triggered();
   void on_actionUpload_triggered();
 
@@ -151,8 +153,6 @@ private:
   void updateUI();
   void setModified(bool modified);
   QModelIndex indexFromPath(const Fm::FilePath & filePath);
-  QGraphicsItem* getImageGraphicsItem();
-  QGraphicsItem* getOutlineGraphicsItem();
 
 private:
   Ui::MainWindow ui;
