@@ -84,6 +84,11 @@ PreferencesDialog::PreferencesDialog(QWidget* parent):
   ui.slideShowInterval->setValue(settings.slideShowInterval());
   ui.oulineBox->setChecked(settings.isOutlineShown());
   ui.annotationBox->setChecked(settings.isAnnotationsToolbarShown());
+  ui.forceZoomFitBox->setChecked(settings.forceZoomFit());
+
+  ui.thumbnailBox->setChecked(settings.showThumbnails());
+  // the max. thumbnail size spinbox is in MiB
+  ui.thumbnailSpin->setValue(qBound(0, settings.maxThumbnailFileSize() / 1024, 1024));
 
   // shortcuts
   initShortcuts();
@@ -138,6 +143,11 @@ void PreferencesDialog::accept() {
   settings.setSlideShowInterval(ui.slideShowInterval->value());
   settings.showOutline(ui.oulineBox->isChecked());
   settings.showAnnotationsToolbar(ui.annotationBox->isChecked());
+  settings.setForceZoomFit(ui.forceZoomFitBox->isChecked());
+
+  settings.setShowThumbnails(ui.thumbnailBox->isChecked());
+  // the max. thumbnail size spinbox is in MiB
+  settings.setMaxThumbnailFileSize(ui.thumbnailSpin->value() * 1024);
 
   applyNewShortcuts();
   settings.save();
@@ -222,7 +232,7 @@ void PreferencesDialog::showWarning(const QString& text, bool temporary) {
       if(warningTimer_ == nullptr) {
         warningTimer_ = new QTimer();
         warningTimer_->setSingleShot (true);
-        connect(warningTimer_, &QTimer::timeout, [this] {
+        connect(warningTimer_, &QTimer::timeout, this, [this] {
           ui.warningLabel->setText(permanentWarning_);
           ui.warningLabel->setVisible(!permanentWarning_.isEmpty());
         });
