@@ -40,7 +40,8 @@ Settings::Settings():
   lastWindowHeight_(480),
   lastWindowMaximized_(false),
   showOutline_(false),
-  showAnnotationsToolbar_(false) {
+  showAnnotationsToolbar_(false),
+  forceZoomFit_(false) {
 }
 
 Settings::~Settings() {
@@ -51,7 +52,6 @@ bool Settings::load() {
   fallbackIconTheme_ = settings.value(QStringLiteral("fallbackIconTheme"), fallbackIconTheme_).toString();
   bgColor_ = settings.value(QStringLiteral("bgColor"), bgColor_).value<QColor>();
   fullScreenBgColor_ = settings.value(QStringLiteral("fullScreenBgColor"), fullScreenBgColor_).value<QColor>();
-  // showThumbnails_;
   // showSidePane_;
   slideShowInterval_ = settings.value(QStringLiteral("slideShowInterval"), slideShowInterval_).toInt();
   maxRecentFiles_ = settings.value(QStringLiteral("maxRecentFiles"), maxRecentFiles_).toInt();
@@ -66,6 +66,7 @@ bool Settings::load() {
   rememberWindowSize_ = settings.value(QStringLiteral("RememberWindowSize"), true).toBool();
   showOutline_ = settings.value(QStringLiteral("ShowOutline"), false).toBool();
   showAnnotationsToolbar_ = settings.value(QStringLiteral("ShowAnnotationsToolbar"), false).toBool();
+  forceZoomFit_ = settings.value(QStringLiteral("ForceZoomFit"), false).toBool();
   prefSize_ = settings.value(QStringLiteral("PrefSize"), QSize(400, 400)).toSize();
   settings.endGroup();
 
@@ -78,6 +79,11 @@ bool Settings::load() {
   }
   settings.endGroup();
 
+  settings.beginGroup(QStringLiteral("Thumbnail"));
+  showThumbnails_ = settings.value(QStringLiteral("ShowThumbnails"), false).toBool();
+  setMaxThumbnailFileSize(qMax(settings.value(QStringLiteral("MaxThumbnailFileSize"), 4096).toInt(), 1024));
+  settings.endGroup();
+
   return true;
 }
 
@@ -100,6 +106,7 @@ bool Settings::save() {
   settings.setValue(QStringLiteral("RememberWindowSize"), rememberWindowSize_);
   settings.setValue(QStringLiteral("ShowOutline"), showOutline_);
   settings.setValue(QStringLiteral("ShowAnnotationsToolbar"), showAnnotationsToolbar_);
+  settings.setValue(QStringLiteral("ForceZoomFit"), forceZoomFit_);
   settings.setValue(QStringLiteral("PrefSize"), prefSize_);
   settings.endGroup();
 
@@ -115,6 +122,11 @@ bool Settings::save() {
   }
   settings.endGroup();
 
+  settings.beginGroup(QStringLiteral("Thumbnail"));
+  settings.setValue(QStringLiteral("ShowThumbnails"), showThumbnails_);
+  settings.setValue(QStringLiteral("MaxThumbnailFileSize"), maxThumbnailFileSize());
+  settings.endGroup();
+
   return true;
 }
 
