@@ -26,6 +26,7 @@
 #include <qcache.h>
 #include <QColor>
 #include <QSize>
+#include <libfm-qt/core/thumbnailjob.h>
 
 namespace LxImage {
 
@@ -70,6 +71,14 @@ public:
     showThumbnails_ = show;
   }
 
+  int maxThumbnailFileSize() const {
+    return Fm::ThumbnailJob::maxThumbnailFileSize();
+  }
+
+  void setMaxThumbnailFileSize(int size) {
+    Fm::ThumbnailJob::setMaxThumbnailFileSize(size);
+  }
+
   bool showSidePane() const {
     return showSidePane_;
   }
@@ -169,6 +178,14 @@ public:
     showAnnotationsToolbar_ = show;
   }
 
+  bool forceZoomFit() const {
+    return forceZoomFit_;
+  }
+
+  void setForceZoomFit(bool on) {
+    forceZoomFit_ = on;
+  }
+
   QSize getPrefSize() const {
     return prefSize_;
   }
@@ -206,6 +223,7 @@ private:
   bool lastWindowMaximized_;
   bool showOutline_;
   bool showAnnotationsToolbar_;
+  bool forceZoomFit_;
 
   QSize prefSize_;
 
