@@ -6,22 +6,22 @@
     <message>
         <location filename="../application.cpp" line="96"/>
         <source>Take a screenshot (deprecated, please use screengrab instead)</source>
-        <translation type="unfinished"></translation>
+        <translation>Maak een schermfoto (verouderd - gebruik hiervoor screengrab)</translation>
     </message>
     <message>
         <location filename="../application.cpp" line="105"/>
         <source>DIR</source>
-        <translation type="unfinished"></translation>
+        <translation>MAP</translation>
     </message>
     <message>
         <location filename="../application.cpp" line="105"/>
         <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
-        <translation type="unfinished"></translation>
+        <translation>Maak een schermfoto en sla deze op in de map zonder een venster te tonen (verouderd - gebruik hiervoor screengrab)</translation>
     </message>
     <message>
         <location filename="../application.cpp" line="111"/>
         <source>[FILE1, FILE2,...]</source>
-        <translation>[Bestand1, Bestand2,...]</translation>
+        <translation>[BESTAND1, BESTAND2, …]</translation>
     </message>
 </context>
 <context>
@@ -51,75 +51,75 @@
 <context>
     <name>LxImage::MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="204"/>
+        <location filename="../mainwindow.cpp" line="207"/>
         <source>About</source>
         <translation>Over</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="205"/>
+        <location filename="../mainwindow.cpp" line="208"/>
         <source>LXImage-Qt - a simple and fast image viewer
 
-Copyright (C) 2013
-LXQt Project: https://lxqt.org/
+Copyright (C) 2013-2020
+LXQt Project: https://lxqt-project.org
 
 Authors:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
-        <translation>LXImage-Qt - een eenvoudige en snelle afbeeldingenkijker
+        <translation>LXImage-Qt - een eenvoudig, snel afbeeldingsprogramma
 
-Auteursrecht (C) 2013
-LXQt-project: https://lxqt.org/
+Copyright (C) 2013-2020
+LXQt-project: https://lxqt-project.org
 
-Auteurs:
+Makers:
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="360"/>
+        <location filename="../mainwindow.cpp" line="363"/>
         <source>Open File</source>
         <translation>Bestand openen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="361"/>
-        <location filename="../mainwindow.cpp" line="396"/>
+        <location filename="../mainwindow.cpp" line="364"/>
+        <location filename="../mainwindow.cpp" line="399"/>
         <source>Image files (%1)</source>
-        <translation>Afbeeldingbestanden (%1)</translation>
+        <translation>Afbeeldingsbestanden (%1)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../mainwindow.cpp" line="377"/>
         <source>Open directory</source>
         <translation>Map openen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="395"/>
+        <location filename="../mainwindow.cpp" line="398"/>
         <source>Save File</source>
         <translation>Bestand opslaan</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="683"/>
+        <location filename="../mainwindow.cpp" line="691"/>
         <source>[*]%1 (Loading...) - Image Viewer</source>
-        <translation>[*]%1 (Laden...) - Afbeeldingkijker</translation>
+        <translation>[*]%1 (Bezig met laden…) - Afbeeldingsweergave</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="689"/>
+        <location filename="../mainwindow.cpp" line="697"/>
         <source>[*]%1 (Failed to Load) - Image Viewer</source>
-        <translation>[*]%1 (Laden mislukt) - Afbeeldingenkijker</translation>
+        <translation>[*]%1 (Laden mislukt) - Afbeeldingsweergave</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="695"/>
+        <location filename="../mainwindow.cpp" line="703"/>
         <source>[*]%1 (%2x%3) - Image Viewer</source>
-        <translation>[*]%1 (%2x%3) - Afbeeldingkijker</translation>
+        <translation>[*]%1 (%2x%3) - Afbeeldingsweergave</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="741"/>
+        <location filename="../mainwindow.cpp" line="749"/>
         <source>[*]Image Viewer</source>
-        <translation>[*]Afbeeldingkijker</translation>
+        <translation>[*]Afbeeldingsweergave</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1167"/>
+        <location filename="../mainwindow.cpp" line="1178"/>
         <source>Thumbnails</source>
         <translation>Miniaturen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1217"/>
+        <location filename="../mainwindow.cpp" line="1228"/>
         <source>EXIF Data</source>
         <translation>EXIF-gegevens</translation>
     </message>
@@ -129,7 +129,7 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     <message>
         <location filename="../mrumenu.cpp" line="49"/>
         <source>&amp;Clear</source>
-        <translation>Maak &amp;leeg</translation>
+        <translation>&amp;Wissen</translation>
     </message>
 </context>
 <context>
@@ -138,17 +138,18 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <location filename="../preferencesdialog.cpp" line="74"/>
         <source>Use a modifier key to clear a shortcut
 in the editing mode.</source>
-        <translation type="unfinished"></translation>
+        <translation>Gebruik een sneltoets om een sneltoets te wissen
+in de bewerkmodus.</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.cpp" line="283"/>
+        <location filename="../preferencesdialog.cpp" line="293"/>
         <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Waarschuwing: dubbelzinnige sneltoets gedetecteerd!&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.cpp" line="300"/>
+        <location filename="../preferencesdialog.cpp" line="310"/>
         <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Dubbelzinnige sneltoets niet geaccepteerd.&lt;/b&gt;</translation>
     </message>
 </context>
 <context>
@@ -156,7 +157,7 @@ in the editing mode.</source>
     <message>
         <location filename="../saveimagejob.cpp" line="54"/>
         <source>Cannot save with this image format!</source>
-        <translation type="unfinished"></translation>
+        <translation>Het bestand kan niet worden opgeslagen naar dit bestandsformaat!</translation>
     </message>
 </context>
 <context>
@@ -164,12 +165,12 @@ in the editing mode.</source>
     <message>
         <location filename="../statusbar.cpp" line="63"/>
         <source>Size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Afmetingen:</translation>
     </message>
     <message>
         <location filename="../statusbar.cpp" line="73"/>
         <source>Path:</source>
-        <translation type="unfinished"></translation>
+        <translation>Locatie:</translation>
     </message>
 </context>
 <context>
@@ -192,22 +193,22 @@ in the editing mode.</source>
     <message>
         <location filename="../upload/uploaddialog.cpp" line="137"/>
         <source>Start</source>
-        <translation>Begin</translation>
+        <translation>Uploaden</translation>
     </message>
     <message>
         <location filename="../upload/uploaddialog.cpp" line="140"/>
         <source>Stop</source>
-        <translation>Stop</translation>
+        <translation>Afbreken</translation>
     </message>
     <message>
         <location filename="../upload/uploaddialog.cpp" line="143"/>
         <source>Close</source>
-        <translation>Sluit</translation>
+        <translation>Sluiten</translation>
     </message>
     <message>
         <location filename="../upload/uploaddialog.cpp" line="150"/>
         <source>Error</source>
-        <translation>Fout</translation>
+        <translation>Foutmelding</translation>
     </message>
 </context>
 <context>
@@ -215,13 +216,13 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <source>Image Viewer</source>
-        <translation>Afbeeldingkijker</translation>
+        <translation>Afbeeldingsweergave</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="188"/>
         <location filename="../mainwindow.ui" line="634"/>
         <source>Annotations Toolbar</source>
-        <translation>Aantekeningenwerkbalk</translation>
+        <translation>Aantekeningwerkbalk</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="208"/>
@@ -237,7 +238,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="241"/>
         <source>&amp;Save</source>
-        <translation>&amp;Opslaan</translation>
+        <translation>Op&amp;slaan</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="244"/>
@@ -267,12 +268,12 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="277"/>
         <source>Zoom &amp;In</source>
-        <translation>Ver&amp;groten</translation>
+        <translation>&amp;Inzoomen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="289"/>
         <source>Zoom &amp;Out</source>
-        <translation>Ver&amp;kleinen</translation>
+        <translation>Uitz&amp;oomen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="292"/>
@@ -282,44 +283,44 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="301"/>
         <source>&amp;Copy to Clipboard</source>
-        <translation>Kopieer naar &amp;klembord</translation>
+        <translation>Kopiëren naar &amp;klembord</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="310"/>
         <location filename="../mainwindow.ui" line="313"/>
         <source>Next File</source>
-        <translation>Volgende bestand</translation>
+        <translation>Volgend bestand</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="325"/>
         <location filename="../mainwindow.ui" line="328"/>
         <source>Previous File</source>
-        <translation>Vorige bestand</translation>
+        <translation>Vorig bestand</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="316"/>
         <source>PgDown</source>
-        <translation>Omlaag</translation>
+        <translation>PgDown</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="67"/>
         <source>Open &amp;With...</source>
-        <translation type="unfinished"></translation>
+        <translation>Openen &amp;met…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="72"/>
         <source>&amp;Recently Opened Files</source>
-        <translation>&amp;Onlangs Geopend</translation>
+        <translation>&amp;Onlangs geopend</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="217"/>
         <source>&amp;Open…</source>
-        <translation>&amp;Open…</translation>
+        <translation>&amp;Openen…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="229"/>
         <source>&amp;Reload File</source>
-        <translation>&amp;Herlaad Bestand</translation>
+        <translation>Bestand he&amp;rladen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="232"/>
@@ -334,7 +335,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="331"/>
         <source>PgUp</source>
-        <translation>Omhoog</translation>
+        <translation>PgUp</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="343"/>
@@ -349,12 +350,12 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="358"/>
         <source>&amp;Fit</source>
-        <translation>Passen&amp;d</translation>
+        <translation>In&amp;passen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="367"/>
         <source>&amp;Rotate Clockwise</source>
-        <translation>Met de klok mee &amp;draaien</translation>
+        <translation>Naar &amp;rechts draaien</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="370"/>
@@ -364,17 +365,17 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="379"/>
         <source>Rotate &amp;Counterclockwise</source>
-        <translation>&amp;Tegen de klok in draaien</translation>
+        <translation>Naar lin&amp;ks draaien</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="382"/>
         <source>L</source>
-        <translation>L</translation>
+        <translation>K</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="387"/>
         <source>P&amp;references</source>
-        <translation>&amp;Voorkeuren</translation>
+        <translation>&amp;Instellingen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="392"/>
@@ -394,7 +395,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="407"/>
         <source>Home</source>
-        <translation>Thuis</translation>
+        <translation>Home</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="416"/>
@@ -404,7 +405,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="419"/>
         <source>End</source>
-        <translation>Einde</translation>
+        <translation>End</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="428"/>
@@ -429,12 +430,12 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="448"/>
         <source>Capture Screenshot</source>
-        <translation>Schermafdruk maken</translation>
+        <translation>Schermfoto maken</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="456"/>
         <source>F&amp;ull Screen</source>
-        <translation>&amp;Volledig Scherm</translation>
+        <translation>Beeldv&amp;ullend</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="459"/>
@@ -444,7 +445,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="464"/>
         <source>Flip &amp;Vertically</source>
-        <translation>Spiegel &amp;verticaal</translation>
+        <translation>&amp;Verticaal spiegelen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="467"/>
@@ -454,27 +455,27 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="476"/>
         <source>&amp;Paste from Clipboard</source>
-        <translation>&amp;Plak vanuit klembord</translation>
+        <translation>Klembord &amp;plakken</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="488"/>
         <source>&amp;Slide Show</source>
-        <translation>&amp;Diapresentatie</translation>
+        <translation>Diavoor&amp;stelling</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="497"/>
         <source>&amp;Delete</source>
-        <translation>&amp;Wis</translation>
+        <translation>Verwij&amp;deren</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="500"/>
         <source>Del</source>
-        <translation>Wis</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="508"/>
         <source>Show Thumbnails</source>
-        <translation>Toon miniaturen</translation>
+        <translation>Miniaturen tonen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="511"/>
@@ -490,7 +491,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="525"/>
         <source>Open &amp;Directory</source>
-        <translation>Open map</translation>
+        <translation>Map o&amp;penen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="528"/>
@@ -500,17 +501,17 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="537"/>
         <source>Upload</source>
-        <translation>Opsturen</translation>
+        <translation>Uploaden</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="540"/>
         <source>Upload the image</source>
-        <translation>Afbeelding opsturen</translation>
+        <translation>Afbeelding uploaden</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="548"/>
         <source>Show EXIF Data</source>
-        <translation>Toon EXIF-gegevens</translation>
+        <translation>EXIF-gegevens tonen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="560"/>
@@ -520,12 +521,12 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="563"/>
         <source>Deselect all drawing tools</source>
-        <translation>Deselecteer alle tekengereedschappen</translation>
+        <translation>Geen tekengereedschap selecteren</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="575"/>
         <source>Draw Arrow</source>
-        <translation>Teken pijl</translation>
+        <translation>Pijl tekenen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="578"/>
@@ -535,27 +536,27 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="590"/>
         <source>Draw Rectangle</source>
-        <translation>Teken rechthoek</translation>
+        <translation>Rechthoek tekenen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="593"/>
         <source>Draw a hollow rectangle</source>
-        <translation>Teken een rechthoek zonder inhoud</translation>
+        <translation>Teken een blanco rechthoek</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="605"/>
         <source>Draw Circle</source>
-        <translation>Teken cirkel</translation>
+        <translation>Cirkel tekenen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="608"/>
         <source>Draw a hollow circle</source>
-        <translation>Teken een cirkel zonder inhoud</translation>
+        <translation>Teken een blanco cirkel</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="620"/>
         <source>Draw Number</source>
-        <translation>Teken getal</translation>
+        <translation>Getal tekenen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="623"/>
@@ -565,13 +566,13 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="631"/>
         <source>&amp;Annotations Toolbar</source>
-        <translation>&amp;Aantekeningenwerkbalk</translation>
+        <translation>&amp;Aantekeningwerkbalk</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="642"/>
         <location filename="../mainwindow.ui" line="645"/>
         <source>Show Outline</source>
-        <translation>Toon contour</translation>
+        <translation>Contour tonen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="648"/>
@@ -581,17 +582,17 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="656"/>
         <source>Copy Pa&amp;th</source>
-        <translation type="unfinished"></translation>
+        <translation>Loca&amp;tie kopiëren</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="659"/>
         <source>Copy path</source>
-        <translation type="unfinished"></translation>
+        <translation>Locatie kopiëren</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="668"/>
         <source>Resize</source>
-        <translation type="unfinished"></translation>
+        <translation>Grootte aanpassen</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="63"/>
@@ -611,12 +612,12 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="110"/>
         <source>&amp;View</source>
-        <translation>&amp;Tonen</translation>
+        <translation>&amp;Beeld</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="128"/>
         <source>&amp;Edit</source>
-        <translation>&amp;Bewerken</translation>
+        <translation>B&amp;ewerken</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="153"/>
@@ -629,7 +630,7 @@ in the editing mode.</source>
     <message>
         <location filename="../preferencesdialog.ui" line="14"/>
         <source>Preferences</source>
-        <translation>Voorkeuren</translation>
+        <translation>Instellingen</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="33"/>
@@ -644,47 +645,72 @@ in the editing mode.</source>
     <message>
         <location filename="../preferencesdialog.ui" line="50"/>
         <source>Fullscreen background color:</source>
-        <translation>Schermvullende achtergrondkleur:</translation>
+        <translation>Achtergrondkleur beeldvullende modus:</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="71"/>
         <source>Maximum number of recent files:</source>
-        <translation type="unfinished"></translation>
+        <translation>Maximumaantal onlangs geopende bestanden:</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="81"/>
         <source>Slide show interval (seconds):</source>
-        <translation>Tussenpoze voor diapresentatie (seconden):</translation>
+        <translation>Diawachttijd (in seconden):</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="95"/>
         <source>Show image outline by default</source>
-        <translation>Toon standaard afbeeldingcontour</translation>
+        <translation>Contouren altijd tonen</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="102"/>
         <source>Show annotations toolbar by default</source>
-        <translation>Toon standaard aantekeningenwerkbalk</translation>
+        <translation>Aantekeningwerkbalk altijd tonen</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="110"/>
+        <location filename="../preferencesdialog.ui" line="109"/>
+        <source>Fit images when navigating</source>
+        <translation>Afbeeldingen inpassen tijdens bladeren</translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="117"/>
+        <source>Thumbnails</source>
+        <translation>Miniaturen</translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="123"/>
+        <source>Image size limit for built-in thumbnailer:</source>
+        <translation>Groottebeperking van ingebouwde miniatuurmaker:</translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="130"/>
+        <source> MiB</source>
+        <translation> MiB</translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="146"/>
+        <source>Show thumbnails dock by default</source>
+        <translation>Altijd miniaturenbalk tonen</translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="154"/>
         <source>Shortcuts</source>
-        <translation type="unfinished"></translation>
+        <translation>Sneltoetsen</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="129"/>
+        <location filename="../preferencesdialog.ui" line="173"/>
         <source>Action</source>
-        <translation type="unfinished"></translation>
+        <translation>Actie</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="134"/>
+        <location filename="../preferencesdialog.ui" line="178"/>
         <source>Shortcut</source>
-        <translation type="unfinished"></translation>
+        <translation>Sneltoets</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="142"/>
+        <location filename="../preferencesdialog.ui" line="186"/>
         <source>Default</source>
-        <translation type="unfinished"></translation>
+        <translation>Standaardwaarden</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="24"/>
@@ -695,9 +721,9 @@ in the editing mode.</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mainwindow.cpp" line="830"/>
+        <location filename="../mainwindow.cpp" line="841"/>
         <source>Error</source>
-        <translation type="unfinished">Fout</translation>
+        <translation>Foutmelding</translation>
     </message>
 </context>
 <context>
@@ -705,44 +731,44 @@ in the editing mode.</source>
     <message>
         <location filename="../resizeimagedialog.ui" line="14"/>
         <source>Resize Image</source>
-        <translation type="unfinished"></translation>
+        <translation>Grootte aanpassen</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="26"/>
         <source>Width</source>
-        <translation type="unfinished"></translation>
+        <translation>Breedte</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="33"/>
         <source>Height</source>
-        <translation type="unfinished"></translation>
+        <translation>Hoogte</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="40"/>
         <source>Current size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Huidige afmetingen:</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="80"/>
         <source>New size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Nieuwe afmetingen:</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="93"/>
         <location filename="../resizeimagedialog.ui" line="116"/>
         <source> px</source>
-        <translation type="unfinished"></translation>
+        <translation> px</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="129"/>
         <location filename="../resizeimagedialog.ui" line="158"/>
         <source> %</source>
-        <translation type="unfinished"></translation>
+        <translation> %</translation>
     </message>
     <message>
         <location filename="../resizeimagedialog.ui" line="174"/>
         <source>Keep aspect ratio</source>
-        <translation type="unfinished"></translation>
+        <translation>Beeldverhouding behouden</translation>
     </message>
 </context>
 <context>
@@ -750,12 +776,12 @@ in the editing mode.</source>
     <message>
         <location filename="../screenshotdialog.ui" line="14"/>
         <source>Screenshot</source>
-        <translation>Schermafdruk</translation>
+        <translation>Schermfoto</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="27"/>
         <source>Take a screenshot</source>
-        <translation>Schermafdruk maken</translation>
+        <translation>Schermfoto maken</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="34"/>
@@ -770,32 +796,32 @@ in the editing mode.</source>
     <message>
         <location filename="../screenshotdialog.ui" line="50"/>
         <source>Current window only</source>
-        <translation>Alleen huidige venster</translation>
+        <translation>Huidig venster</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="57"/>
         <source>Capture an area of the screen</source>
-        <translation>Fotografeer een deel van het scherm</translation>
+        <translation>Gebied selecteren</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="67"/>
         <source>Include mouse cursor</source>
-        <translation>Inclusief muisaanwijzer</translation>
+        <translation>Cursor tonen</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="74"/>
         <source> sec</source>
-        <translation type="unfinished"></translation>
+        <translation> sec</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="91"/>
         <source>Delay:</source>
-        <translation>Vertraging:</translation>
+        <translation>Wachttijd:</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="101"/>
         <source>Include window title and frame</source>
-        <translation>Inclusief venstertitel en rand</translation>
+        <translation>Venstertitel en -rand tonen</translation>
     </message>
 </context>
 <context>
@@ -803,7 +829,7 @@ in the editing mode.</source>
     <message>
         <location filename="../upload/uploaddialog.ui" line="14"/>
         <source>Upload</source>
-        <translation>Opsturen</translation>
+        <translation>Uploaden</translation>
     </message>
     <message>
         <location filename="../upload/uploaddialog.ui" line="39"/>
